@@ -1,10 +1,9 @@
-use crate::{generate_python_exception_string, RustIUMQTT};
+use crate::{print_python_exception, RustIUMQTT};
 use ipaacar_core::components;
 use pyo3::exceptions::{PyNotImplementedError, PyTypeError};
 use pyo3::prelude::{PyAnyMethods, PyModule};
 use pyo3::{pyclass, pymethods, Bound, Py, PyAny, PyErr, PyResult, Python};
 use std::sync::Arc;
-use log::error;
 use tokio::sync::RwLock;
 use uuid::Uuid;
 use crate::pyo3_asyncio;
@@ -377,8 +376,9 @@ impl IU {
                             .unwrap()
                     });
                     if let Err(e) = cor.await {
-                        let err_msg = generate_python_exception_string(e);
-                        error!("executing on_update callback for IU {iu_id} failed:\n{err_msg}");
+                        print_python_exception(e);
+                        // let err_msg = generate_python_exception_string(e);
+                        // error!("executing on_update callback for IU {iu_id} failed:\n{err_msg}");
                     }
                 })
             })
